==> opencascade_7.4.1+dfsg1.orig.tar.xz: occt-V7_4_0p1/src/Graphic3d/Graphic3d_AspectText3d.cxx <==
// Created by: NW,JPB,CAL
// Copyright (c) 1991-1999 Matra Datavision
// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

#include <Graphic3d_AspectText3d.hxx>

IMPLEMENT_STANDARD_RTTIEXT(Graphic3d_AspectText3d, Graphic3d_Aspects)

// =======================================================================
// function : Graphic3d_AspectText3d
// purpose  :
// =======================================================================
Graphic3d_AspectText3d::Graphic3d_AspectText3d()
{
  // actually this should be a special state Graphic3d_AlphaMode_MaskBlend
  // since text is drawn in usual order with normal opaque objects (thanks to alpha test),
  // but blending is also enabled to smoothen boundaries
  SetAlphaMode (Graphic3d_AlphaMode_Mask, 0.285f);
  myShadingModel = Graphic3d_TOSM_UNLIT;
  myInteriorColor.SetRGB (Quantity_NOC_YELLOW);
  myEdgeColor.SetRGB (Quantity_NOC_WHITE);
}

// =======================================================================
// function : Graphic3d_AspectText3d
// purpose  :
// =======================================================================
Graphic3d_AspectText3d::Graphic3d_AspectText3d (const Quantity_Color& theColor,
                                                Standard_CString theFont,
                                                Standard_Real ,
                                                Standard_Real ,
                                                Aspect_TypeOfStyleText   theStyle,
                                                Aspect_TypeOfDisplayText theDisplayType)
{
  SetAlphaMode (Graphic3d_AlphaMode_Mask, 0.285f);
  myShadingModel = Graphic3d_TOSM_UNLIT;
  myTextStyle = theStyle;
  myTextDisplayType = theDisplayType;
  myInteriorColor.SetRGB (theColor);
  myEdgeColor.SetRGB (Quantity_NOC_WHITE);
  if (theFont != NULL
  && *theFont != '\0')
  {
    myTextFont = new TCollection_HAsciiString (theFont);
  }
}

==> opencascade_7.5.1+dfsg1.orig.tar.xz: occt-V7_5_1/src/Graphic3d/Graphic3d_AspectText3d.cxx <==
// Created by: NW,JPB,CAL
// Copyright (c) 1991-1999 Matra Datavision
// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

#include <Graphic3d_AspectText3d.hxx>

IMPLEMENT_STANDARD_RTTIEXT(Graphic3d_AspectText3d, Graphic3d_Aspects)

// =======================================================================
// function : Graphic3d_AspectText3d
// purpose  :
// =======================================================================
Graphic3d_AspectText3d::Graphic3d_AspectText3d()
{
  // actually this should be a special state Graphic3d_AlphaMode_MaskBlend
  // since text is drawn in usual order with normal opaque objects (thanks to alpha test),
  // but blending is also enabled to smoothen boundaries
  SetAlphaMode (Graphic3d_AlphaMode_Mask, 0.285f);
  myShadingModel = Graphic3d_TOSM_UNLIT;
  myInteriorColor.SetRGB (Quantity_NOC_YELLOW);
  myEdgeColor.SetRGB (Quantity_NOC_WHITE);
}

// =======================================================================
// function : Graphic3d_AspectText3d
// purpose  :
// =======================================================================
Graphic3d_AspectText3d::Graphic3d_AspectText3d (const Quantity_Color& theColor,
                                                Standard_CString theFont,
                                                Standard_Real ,
                                                Standard_Real ,
                                                Aspect_TypeOfStyleText   theStyle,
                                                Aspect_TypeOfDisplayText theDisplayType)
{
  SetAlphaMode (Graphic3d_AlphaMode_Mask, 0.285f);
  myShadingModel = Graphic3d_TOSM_UNLIT;
  myTextStyle = theStyle;
  myTextDisplayType = theDisplayType;
  myInteriorColor.SetRGB (theColor);
  myEdgeColor.SetRGB (Quantity_NOC_WHITE);
  if (theFont != NULL
  && *theFont != '\0')
  {
    myTextFont = new TCollection_HAsciiString (theFont);
  }
}

// =======================================================================
// function : DumpJson
// purpose  :
// =======================================================================
void Graphic3d_AspectText3d::DumpJson (Standard_OStream& theOStream, Standard_Integer theDepth) const
{
  OCCT_DUMP_TRANSIENT_CLASS_BEGIN (theOStream)
  OCCT_DUMP_BASE_CLASS(theOStream, theDepth, Graphic3d_Aspects)
}
